=== modified file 'dhis-2/dhis-api/src/main/java/org/hisp/dhis/organisationunit/OrganisationUnitGroupService.java'
--- dhis-2/dhis-api/src/main/java/org/hisp/dhis/organisationunit/OrganisationUnitGroupService.java	2009-05-13 15:51:02 +0000
+++ dhis-2/dhis-api/src/main/java/org/hisp/dhis/organisationunit/OrganisationUnitGroupService.java	2009-09-07 15:53:27 +0000
@@ -205,4 +205,13 @@
      * @return an OrganisationUnitGroup.
      */
     OrganisationUnitGroup getOrganisationUnitGroup( OrganisationUnitGroupSet groupSet, OrganisationUnit unit );
+    
+    /**
+     * Returns a Collection of compulsory OrganisationUnitGroupSets whichs groups 
+     * the given OrganisationUnit is not a member of.
+     * 
+     * @param organisationUnit the OrganisationUnit.
+     * @return a Collection of OrganisationUnitGroupSets.
+     */
+    Collection<OrganisationUnitGroupSet> getCompulsoryOrganisationUnitGroupSetsNotAssignedTo( OrganisationUnit organisationUnit );
 }

=== modified file 'dhis-2/dhis-services/dhis-service-organisationunit/src/main/java/org/hisp/dhis/organisationunit/DefaultOrganisationUnitGroupService.java'
--- dhis-2/dhis-services/dhis-service-organisationunit/src/main/java/org/hisp/dhis/organisationunit/DefaultOrganisationUnitGroupService.java	2009-06-10 22:25:07 +0000
+++ dhis-2/dhis-services/dhis-service-organisationunit/src/main/java/org/hisp/dhis/organisationunit/DefaultOrganisationUnitGroupService.java	2009-09-07 15:53:27 +0000
@@ -229,4 +229,24 @@
         
         return null;
     }
+    
+    public Collection<OrganisationUnitGroupSet> getCompulsoryOrganisationUnitGroupSetsNotAssignedTo( OrganisationUnit organisationUnit )
+    {
+        Collection<OrganisationUnitGroupSet> groupSets = new ArrayList<OrganisationUnitGroupSet>();
+        
+        groupSetLoop : for ( OrganisationUnitGroupSet groupSet : getCompulsoryOrganisationUnitGroupSets() )
+        {
+            for ( OrganisationUnitGroup group : groupSet.getOrganisationUnitGroups() )
+            {
+                if ( group.getMembers().contains( organisationUnit ) )
+                {
+                    continue groupSetLoop;
+                }
+            }
+            
+            groupSets.add( groupSet );
+        }
+        
+        return groupSets;
+    }
 }

